@@ -185,7 +185,7 @@ void GLWidget::initializeGL()
 	textures = new GLuint[1];		
 	tbuffers = new GLuint[2];
 	glGenBuffers(2, &tbuffers[0]);
-	string nammi = "/usr/share/mushrooms/md2model.md2";
+	string nammi = "/opt/mushrooms/md2model.md2";
 	string nammitexture = ":/textures/nainen.jpg";
 	md2 = new MD2Model();
 	md2->ReadMD2Model(nammi.c_str(), nammitexture.c_str(), &modelfile);
